@@ -26,7 +26,7 @@ around CLI => sub ( $orig, $self ) {
 };
 
 sub _build_redis_ver ($self) {
-    return $self->cfg->{REDIS}->{REDIS_VER} || $ENV->get_dist('pcore-redis')->cfg->{REDIS}->{REDIS_VER};
+    return $self->cfg->{REDIS}->{REDIS_VER} || $ENV->dist('Pcore-Redis')->cfg->{REDIS}->{REDIS_VER};
 }
 
 # APP
