@@ -1,6 +1,6 @@
 package Pcore::Handle::Redis;
 
-use Pcore qw[-class];
+use Pcore -class;
 use RedisDB;
 
 with qw[Pcore::Core::H::Role::Wrapper];
